"""
asciidoc_writer.py

AsciiDoc writing class which uses the css writer to generate HTML output
with the standard AsciiDoc style sheets.

Copyright (C) 2003 David Boddie <david@boddie.org.uk>

This software is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License as
published by the Free Software Foundation; either version 2 of
the License, or (at your option) any later version.

This software is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public
License along with this library; see the file COPYING
If not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

"""

import commands, os, select


standard_error_message = \
"""
<html>
<head>
  <title>Problem encountered with source text</title>
</head>

<body>

<h1>Problem encountered</h1>

<p>
  Input command:
</p>

<pre>
  %s
</pre>

<p>
  A problem was encountered when attempting to process the source text:
</p>

<pre>
  %s
</pre>

</body>
</html>
"""

class HTMLWriter:

    def __init__(self):
    
        self.writer = "css-embedded"
    
    def write(self, text, url):
    
        self.text = text
        self.url = url
    
    def output(self, export = 0):
    
        # Run a command using the popen2.popen3 function to generate the
        # HTML output.
        
        command = "cat | asciidoc.py -b %s -" % self.writer
        
        data = self.remote_process(command, self.text)
        
        if data is None:
        
            return standard_error_message % (
                str(self.html_repr(command)), str(self.html_repr(self.error))
                )
        
        return data
    
    def remote_process(self, command, data):
    
        si, so, se = os.popen3(command)
        output = []
        
        length = len(data)
        
        total = 0
        ptr = 0
        
        while not (so.closed and si.closed):
        
            if not so.closed:
                reading = [so]
            else:
                reading = []
            
            if not si.closed:
                writing = [si]
            else:
                writing = []
            
            if not se.closed:
                others = [se]
            else:
                others = []
            
            r, w, x = select.select(reading, writing, others)
            
            if x != []:
            
                # Data on stderr
                self.error = x[0].read()
                return None
            
            elif w != []:
            
                # stdin available for writing
                if ptr < length:
                
                    w[0].write(data[ptr:ptr+1024])
                    ptr = ptr + 1024
                
                else:
                
                    w[0].close()
            
            if r != []:
            
                # Data available on stdout
                retrieved = r[0].read(1024)
                
                total = total + len(retrieved)
                
                if len(retrieved) == 0:
                
                    r[0].close()
                
                else:
                
                    output.append(retrieved)
            
            elif r == [] and w == []:
            
                # No input or output streams available.
                return None
        
        return "".join(output)
    
    def html_repr(self, s):
    
        new = []
        
        for c in unicode(s):
        
            if c == u"&":
                new.append(u"&amp;")
            elif c == u"<":
                new.append(u"&lt;")
            elif c == u">":
                new.append(u"&gt;")
            else:
                new.append(c)
        
        return u"".join(new)
