"""
doxygen.py

DOXYGEN writing class.

Copyright (C) 2003 David Boddie <david@boddie.org.uk>

This software is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License as
published by the Free Software Foundation; either version 2 of
the License, or (at your option) any later version.

This software is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public
License along with this library; see the file COPYING
If not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

"""


import popen2, os, shutil

if not os.__dict__.has_key("extsep"):

    os.extsep = "."


error_page = \
u"""
<html>
<head>
  <title>Processing Error</title>
</head>

<body>
<h1>Processing Error</h1>

<p>
  An error occurred when processing <tt>%(url)s</tt>
</p>

</body>
</html>
"""

standard_config = \
u"""
INPUT = %(input)s
DISABLE_INDEX = YES
GENERATE_HTML = YES
HTML_OUTPUT = %(html_output)s
PROJECT_NAME = "%(url)s"
"""

standard_header = \
"""
<HTML>
<HEAD>
  <TITLE>%(url)s</TITLE>
  <STYLE TYPE="text/css">
%(styles)s
  </STYLE>
</HEAD>
<BODY BGCOLOR="#FFFFFF">

"""

standard_footer = \
u"""
</BODY>
</HTML>
"""


class HTMLWriter:

    def __init__(self):
    
        # Create a temporary directory.
        self.tmpdir = os.tmpnam()
        
        try:
        
            os.mkdir(self.tmpdir)
        
        except OSError:
        
            self.tmpdir = None
        
        print self.tmpdir
    
    def __del__(self):
    
        shutil.rmtree(tmpdir)
    
    def write(self, text, url):
    
        if not self.tmpdir:
        
            self.html = error_page % {"url": url}
            return
        
        # DOXYGEN can't read text in from standard input and we have to
        # create a configuration file anyway. Still, we will pass the
        # configuration file via standard input and try and read the
        # output via standard output.
        
        at = url.find(u":")
        
        if at == -1:
        
            input_file = url
        
        elif url[:at] == u"file":
        
            input_file = url[at+1:]
        
        else:
        
            self.html = error_page % {"url": url}
            return
        
        # Write a configuration file in the directory.
        try:
        
            config_file = os.path.join(self.tmpdir, "Doxyfile")
            open(config_file, "w").write(
                standard_config % \
                    {
                        "input": input_file,
                        "url": url,
                        "html_output": self.tmpdir
                    }
                )
        
        except IOError:
        
            self.html = error_page % {"url": url}
            return
        
        # Process the source text.
        styles_file = os.path.join(self.tmpdir, "doxygen.css")
        
        stdout, stdin, stderr = popen2.popen3(
            "doxygen %s -w html - - %s" % (config_file, styles_file)
            )
        
        stdin.close()
        
        error = stderr.read()
        
        # Read the header, footer and styles, inserting the styles
        # and URL into the header before concatenating the body and
        # footer.
        
        try:
        
            styles = open(styles_file).read()
            body = open(
                os.path.join(self.tmpdir, "index" + os.extsep + "html")
                ).read()
        
        except IOError:
        
            #self.html = error_page % {"url": url}
            raise
        
        else:
        
            header = standard_header % {"url": url, "styles": styles}
            self.html = header + unicode(body) + standard_footer
    
    def output(self, export = 0):
    
        # Return the generated HTML.
        return self.html
