import string

"""
details.py

Build and installation details for this PyKDE component.

Copyright (C) 2003 David Boddie <david@boddie.org.uk>

This software is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License as
published by the Free Software Foundation; either version 2 of
the License, or (at your option) any later version.

This software is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public
License along with this library; see the file COPYING
If not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

"""

def find_details():

    details = \
    {
        # Project name - the filename of the Python module should
        # be derived from this: e.g. DefaultPython -> defaultpython.py
        "name":             "SpritePart",
        
        # A pretty name for this module and its description
        "pretty name":      "Viewer for Acorn Spritefiles",
        "comment":          "KPart for embedding in Konqueror",
        
        # Change this function or class name in your Python module to match
        # the name of the factory class.
        "factory":          "FactoryClass",
        
        # Destination filename in each destination for the icons described
        # below.
        "icon":             "pyspritepart.png",
        
        # Specific KParts attributes
        "parent":           "konqueror",
        "C++ factory":      ("init_", "libspritepart")
    }
    
    requires = \
    {
        "library":     "pykpart_launcher.cpp",
        
        # Specify other libraries beneath the Python library directory.
        # A None value for the path causes the module to be searched for
        # within the Python library directories.
        "pyqt": [], "pykde": [],
        
        #"python":       [("spriteops", None)],
        #"python":       [("qt", "site-packages")],
        "python": [],
        
        # Specify other items to include alongside the module in its own
        # directory.
        "other items":  ["image.png", "spritefile.py"]
    }
    
    provides = \
    {
        ".py":
        {
            "filename":     string.lower(details["name"]),
            "directory":    string.lower(details["name"]),
            "destination":  "%(kde dir)s/share/apps"
        },
        
        ".so":
        {
            "name":         string.lower(details["name"]),
            "filename":     "lib" + string.lower(details["name"]),
            "destination":  "%(kde dir)s/lib/kde3"
        },
        
        ".la":
        {
            "contents":     linking_template,
            "filename":     "lib" + string.lower(details["name"]),
            "destination":  "%(kde dir)s/lib/kde3"
        },
        
        ".desktop":
        {
            # Give the path beneath which the desktop file should be stored.
            "filename":     string.lower(details["name"]),
            "destination":  "%(kde dir)s/share/applnk/Graphics",
            "contents":     desktop_template
        },
        
        "icons":
        {
            "destination":  "%(kde dir)s/share/icons/",
            
            # The section under which the icon will be stored for each theme
            # and size.
            "icon type":    "apps",
            
            "themes":
            {
              #   Theme          Size    Source icon
                "hicolor":    { "32x32": [("image.png", "pyspritepart.png")] },
                "crystalsvg": { "32x32": [("image.png", "pyspritepart.png")] },
                "kdeclassic": { "32x32": [("image.png", "pyspritepart.png")] }
            }
        }
    }
    
    return details, requires, provides


desktop_template = \
"""[Desktop Entry]
Name=%(pretty name)s
Comment=%(comment)s
Icon=%(icon)s
MimeType=image/x-spritefile
Type=Application
ServiceTypes=Browser/View
X-KDE-Library=%(lib)s
"""


def hints():

    # Provide hints on how to display the details returned by find_details
    # in a graphical user interface. The dictionary returned contains entries
    # for the details, requires and provides dictionaries, each of which
    # takes the form of a substitution dictionary.
    # In addition, the titles of each dictionary can be substituted if
    # entries for "Details", "Provides" and "Requires" are included.
    
    hint_dict = \
    {
        "Details":      "&Details",
        "Requires":     "&Requires",
        "Provides":     "Provides",    # not usually used
        "Information":  "&Information",
        
        # Substitute the following keys with their corresponding values when
        # displaying information from the provides dictionary.
        
        "provides":
        {
            ".py":      "&Python",
            ".desktop": "Desk&top"
        }
    }
    
    return hint_dict


def info():

    # Return information on the component in HTML format.
    return component_info_html

component_info_html = \
"""<html>
<head>
  <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
  <title>Information about the PySpritePart KPart</title>
</head>

<body>

<h1>PySpritePart</h1>

<h2>Description</h2>

<p>
  A demonstration KPart written in Python to allow the user to view Acorn
  Spritefiles.
</p>

<h2>Notes</h2>

<p>
  This plugin requires the <em>spritefile</em> Python module. See
  <a href="http://www.boddie.org.uk/david/Projects/Python/Spritefile/">this
  page</a> for details.
</p><p>
  To view the contents of Spritefiles it is first necessary to define a
  <strong>non-standard</strong> MIME type <tt>image/x-spritefile</tt> in
  the <em>File Associations</em> section of Konqueror's configuration dialog
  and associate it with a suitable extension for this sort of file.
  Now, specifying <tt>sprites:</tt> instead of <tt>file:</tt> when
  specifying URLs to such files will cause the IOSlave to act.
</p><p>
  Ideally, a standard MIME type would be used; customise the <tt>mimetype</tt>
  line of the protocol file to achieve this.
</p>

<hr>

<address>
David Boddie
&lt;<a href="mailto:david@boddie.org.uk">david@boddie.org.uk</a>&gt;
</address>

</body>
</html>
"""


# Do not change anything below this line. -------------------------------------

linking_template = \
"""
# %(lib)s.la - a libtool library file
# Generated by build.py
#
# Please DO NOT delete this file!
# It is necessary for linking the library.

# The name that we can dlopen(3).
dlname='%(lib)s.so'

# Names of this library.
library_names='%(lib)s.so %(lib)s.so %(lib)s.so'

# The name of the static archive.
old_library=''

# Libraries that this one depends upon.
dependency_libs='%(deps)s'

# Version information for %(lib)s.
current=0
age=0
revision=0

# Is this an already installed library?
installed=yes

# Files to dlopen/dlpreopen
dlopen=''
dlpreopen=''

# Directory that this library needs to be installed in:
libdir='%(libdest)s'
"""
