import string

"""
details.py

Build and installation details for this PyKDE component.

Copyright (C) 2005 David Boddie <david@boddie.org.uk>

This software is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License as
published by the Free Software Foundation; either version 2 of
the License, or (at your option) any later version.

This software is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public
License along with this library; see the file COPYING
If not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

"""

def find_details():

    details = \
    {
        # Project name - the filename of the Python module should
        # be derived from this: e.g. DefaultPython -> defaultpython.py
        "name":             "reSTPart",
        
        # A pretty name for this module and its description
        "pretty name":      "reStructuredText KPart",
        "comment":          "View reStructuredText documents",
        
        # Change this function or class name in your Python module to match
        # the name of the factory class.
        "factory":          "FactoryClass",
        
        # Destination filename in each destination for the icons described
        # below.
        "icon":             "restpart.png",
        
        # Specific KParts attributes
        "parent":           "konqueror",
        "C++ factory":      ("init_", "librestpart")
    }
    
    requires = \
    {
        "library":     "pykpart_launcher.cpp",
        
        # Specify the PyKDE libraries required by this applet.
        "pykde":        [],
        
        # Specify the PyQt libraries required by this applet.
        "pyqt":         [],
        
        # Specify other libraries beneath the Python library directory.
        # A None value for the path causes the module to be searched for
        # within the Python library directories.
        "python":       [],
        
        # Specify other items to include alongside the module in its own
        # directory.
        "other items":  ["reST_writer.py"]
    }
    
    provides = \
    {
        ".py":
        {
            "filename":     string.lower(details["name"]),
            "directory":    string.lower(details["name"]),
            "destination":  "%(kde dir)s/share/apps"
        },
        
        ".so":
        {
            "name":         string.lower(details["name"]),
            "filename":     "lib" + string.lower(details["name"]),
            "destination":  "%(kde dir)s/lib/kde3"
        },
        
        ".la":
        {
            "contents":     linking_template,
            "filename":     "lib" + string.lower(details["name"]),
            "destination":  "%(kde dir)s/lib/kde3"
        },
        
        ".desktop":
        {
            # Give the path beneath which the desktop file should be stored.
            "filename":     string.lower(details["name"]),
            "destination":  "%(kde dir)s/share/services",
            "contents":     desktop_template
        },
        
        ".rc":
        {
            # Give the path beneath which the rc file should be stored.
            "filename":     string.lower(details["name"]),
            "destination":  "%(kde dir)s/share/apps/",
            "directory":    string.lower(details["name"]),
            "contents":     rc_template
        },
        
        "icons":
        {
            "destination":  "%(kde dir)s/share/icons/",
            
            # The section under which the icon will be stored for each theme
            # and size.
            "icon type":    "actions",
            
            "themes":
            {
              #   Theme          Size    Source icon
                "hicolor":
                {
                    "64x64": [ ("Icons/icon-64x64.png",   "restpart.png") ],
                    "32x32": [ ("Icons/icon-32x32.png",   "restpart.png") ],
                    "22x22": [ ("Icons/icon-32x32.png",   "restpart.png") ],
                    "16x16": [ ("Icons/icon-32x32.png",   "restpart.png") ]
                },
                "crystalsvg":
                {
                    "64x64": [ ("Icons/icon-64x64.png",   "restpart.png") ],
                    "32x32": [ ("Icons/icon-32x32.png",   "restpart.png") ],
                    "22x22": [ ("Icons/icon-32x32.png",   "restpart.png") ],
                    "16x16": [ ("Icons/icon-32x32.png",   "restpart.png") ]
                },
                "kdeclassic":
                {
                    "64x64": [ ("Icons/icon-64x64.png",   "restpart.png") ],
                    "32x32": [ ("Icons/icon-32x32.png",   "restpart.png") ],
                    "22x22": [ ("Icons/icon-32x32.png",   "restpart.png") ],
                    "16x16": [ ("Icons/icon-32x32.png",   "restpart.png") ]
                }
            }
        }
    }
    
    return details, requires, provides


desktop_template = \
"""[Desktop Entry]
Name=%(pretty name)s
Comment=%(comment)s
Icon=%(icon)s
MimeType=text/plain;text/x-readme
Type=Service
ServiceTypes=KParts/ReadWritePart,Browser/View
X-KDE-Library=%(lib)s
"""

rc_template = \
"""<!DOCTYPE kpartgui>
<kpartplugin name="%(name)s" library="%(lib)s">
<MenuBar>
  <Menu name="file"><Text>&amp;Location</Text>
    <Action name="reSTsavehtml"/>
  </Menu>
</MenuBar>
</kpartgui>
"""


def hints():

    # Provide hints on how to display the details returned by find_details
    # in a graphical user interface. The dictionary returned contains entries
    # for the details, requires and provides dictionaries, each of which
    # takes the form of a substitution dictionary.
    # In addition, the titles of each dictionary can be substituted if
    # entries for "Details", "Provides" and "Requires" are included.
    
    hint_dict = \
    {
        "Details":      "&Details",
        "Requires":     "&Requires",
        "Provides":     "Provides",    # not usually used
        "Information":  "&Information",
        
        # Substitute the following keys with their corresponding values when
        # displaying information from the provides dictionary.
        
        "provides":
        {
            ".py":      "&Python",
            ".desktop": "Desk&top",
            ".rc":      "I&nterface"
        }
    }
    
    return hint_dict


def info():

    # Return information on the component in HTML format.
    return component_info_html

component_info_html = \
"""<html>
<head>
  <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
  <title>Information about the reStructuredText KPart</title>
</head>

<body>

<h1>reStructuredText Viewer</h1>

<h2>Description</h2>

<p>
  A KPart for editing Wiki-style content in Konqueror using standard text
  editing KParts and KHTML.
</p>

<h2>Usage</h2>

<p>
  By default, this KPart is associated with the <tt>text/plain</tt> and
  <tt>text/x-readme</tt> MIME types. To use it for editing files of either
  MIME type, perform the following actions:
  
  <ol>
  <li>Open the <em>File Associations</em> section of Konqueror's
      configuration dialog.
  <li>Select the relevant MIME type from the list.
  <li>Select the <em>Embedding</em> tab.
  <li>In the <em>Services Preference Order</em> section, click the
      <em>Add...</em> button and select the <em>Embedded Wiki KPart</em>.
  </ol>
  
  This can be repeated for each of the required MIME types. Note that
  only the above MIME types have been defined in the desktop file for this
  KPart; to allow more to be used, edit the desktop file generated by the
  build process (<tt>embedwikiplugin.desktop</tt>).
</p>

<h2>Notes</h2>

<p>
  ReStructuredText support is only available if you install the Docutils
  package from
</p><p>
  <tt>http://docutils.sourceforge.net/</tt>
</p>

<hr>

<address>
David Boddie
&lt;<a href="mailto:david@boddie.org.uk">david@boddie.org.uk</a>&gt;
</address>

</body>
</html>
"""


# Do not change anything below this line. -------------------------------------

linking_template = \
"""
# %(lib)s.la - a libtool library file
# Generated by build.py
#
# Please DO NOT delete this file!
# It is necessary for linking the library.

# The name that we can dlopen(3).
dlname='%(lib)s.so'

# Names of this library.
library_names='%(lib)s.so %(lib)s.so %(lib)s.so'

# The name of the static archive.
old_library=''

# Libraries that this one depends upon.
dependency_libs='%(deps)s'

# Version information for %(lib)s.
current=0
age=0
revision=0

# Is this an already installed library?
installed=yes

# Files to dlopen/dlpreopen
dlopen=''
dlpreopen=''

# Directory that this library needs to be installed in:
libdir='%(libdest)s'
"""
