"""
ReST_writer.py

ReStructuredText writing class based on the html.py front end to the
Docutils Publisher class, written by David Goodger. See the tools
directory in the Docutils distribution for more information.

Copyright (C) 2003 David Boddie <david@boddie.org.uk>

This software is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License as
published by the Free Software Foundation; either version 2 of
the License, or (at your option) any later version.

This software is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public
License along with this library; see the file COPYING
If not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

"""


import locale
try:
    locale.setlocale(locale.LC_ALL, '')
except:
    pass

from docutils.core import publish_string, default_description

import sys, traceback


# Define a standard page for error reporting.

standard_error = \
"""<html>
<head>
  <title>Processing Error</title>
</head>

<body>

<h1>Processing Error</h1>

<pre>
%s
</pre>

</body>
</html>
"""


class HTMLWriter:

    def __init__(self):
    
        self.settings = \
        {
            "input_encoding": "unicode",
            "output_encoding": "unicode"
        }
        
        self.writer = "html"
    
    def write(self, text, url):
    
        self.text = text
        self.url = url
    
    def output(self, export = 0):
    
        # Use the publish string function to generate HTML from the original
        # text.
        
        try:
        
            html = publish_string(
                self.text,
                writer_name = self.writer,
                settings_overrides = self.settings
                )
        
        except StandardError:
        
            lines = traceback.format_exception( *(sys.exc_info()) )
            
            for i in range(len(lines)-1, -1, -1):
            
                if lines[i].find("<string>"): break
            
            text = "\n".join(lines[i:])
            
            html = standard_error % self.html_repr(text)
        
        return html
    
    def html_repr(self, s):
    
        new = []
        
        for c in unicode(s):
        
            if c == u"&":
                new.append(u"&amp;")
            elif c == u"<":
                new.append(u"&lt;")
            elif c == u">":
                new.append(u"&gt;")
            else:
                new.append(c)
        
        return u"".join(new)
